import { createContext, useContext, createElement as createElement$1, useMemo, Fragment } from 'react';
import '../Provider/ThemeContext.js';
import 'classnames';
import 'emotion';
import '@emotion/core';
import 'emotion-theming';
import '@emotion/styled';
import '../utils/useTheme.js';
import { d as _objectWithoutPropertiesLoose, _ as _objectSpread2, c as _extends } from '../chunk-0c448560.js';
import 'lodash/kebabCase';
import 'tinycolor2';
import '../utils/isFunction.js';
import '../utils/get.js';
import '../utils/theme.js';
import '../utils/omit.js';
import '../utils/pick.js';
import '../utils/cssProps.js';
import '../utils/useLocalStorage.js';
import '../Provider/ColorModeContext.js';
import '../utils/useColorMode.js';
import '../utils/useStyle.js';
import '../utils/omitBy.js';
import '../utils/useDefaultProps.js';
import '../utils/useDebounce.js';
import 'lodash/uniq';
import { useClassName } from '../utils/useClassName.js';
import '../utils/useBreakpoint.js';
import { useUniqueId } from '../utils/uniqueId.js';
import '../utils/times.js';
import '../utils/parseIcons.js';
import '../utils/colors.js';
import '../utils/palette.js';
import '../utils/mergeRefs.js';
import 'deepmerge';
import 'lodash/set';
import '../utils/applyTheme.js';
import '../utils/bindFns.js';
import { createComponent } from '../utils/createComponent.js';
import { createElement } from '../utils/createElement.js';
import { createHook } from '../utils/createHook.js';
import '../utils/forwardRefWithUse.js';
import '../utils/fieldAdaptors.js';
import '@emotion/is-prop-valid';
import '../utils/htmlProps.js';
import '../utils/OutsideClickHandler.js';
import { Box } from 'reakit';
import '../Box/styles-579aeb3a.js';
import { Box as Box$1 } from '../Box/Box.js';
import { a as CardContent$1, c as CardTitle$1, b as CardHeader$1, d as CardFooter$1, C as Card$1 } from './styles-6b29b6fa.js';

var CardContext = createContext({});
var useProps = createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var footer = props.footer,
      headerAddon = props.headerAddon,
      overrides = props.overrides,
      standalone = props.standalone,
      title = props.title,
      variant = props.variant,
      restProps = _objectWithoutPropertiesLoose(props, ["footer", "headerAddon", "overrides", "standalone", "title", "variant"]);

  var boxProps = Box$1.useProps(_objectSpread2({
    altitude: variant === 'shadowed' ? '100' : null,
    border: variant === 'bordered' ? 'default' : null
  }, restProps));
  var className = useClassName({
    style: Card$1,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var titleId = useUniqueId('cardTitle');
  var descriptionId = useUniqueId('cardDescription');
  var context = useMemo(function () {
    return _objectSpread2({
      descriptionId: descriptionId,
      titleId: titleId
    }, props);
  }, [descriptionId, props, titleId]);
  var children = /*#__PURE__*/createElement$1(CardContext.Provider, {
    value: context
  }, standalone ? props.children : /*#__PURE__*/createElement$1(Fragment, null, title && /*#__PURE__*/createElement$1(CardHeader, {
    overrides: overrides
  }, /*#__PURE__*/createElement$1(CardTitle, {
    overrides: overrides
  }, title), headerAddon && /*#__PURE__*/createElement$1(Box$1, null, headerAddon)), /*#__PURE__*/createElement$1(CardContent, {
    overrides: overrides
  }, props.children), footer && /*#__PURE__*/createElement$1(CardFooter, {
    overrides: overrides
  }, footer)));
  return _objectSpread2(_objectSpread2({
    'aria-describedby': props.children ? descriptionId : undefined,
    'aria-labelledby': props.title ? titleId : undefined
  }, boxProps), {}, {
    className: className,
    children: children
  });
}, {
  defaultProps: {
    variant: 'shadowed'
  },
  themeKey: 'Card'
});
var Card = createComponent(function (props) {
  var cardProps = useProps(props);
  return createElement({
    children: props.children,
    component: Box,
    use: props.use,
    htmlProps: cardProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Card'
  },
  themeKey: 'Card'
}); /////////////////////////////////////

function CardContent(props) {
  var children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["children"]);

  var context = useContext(CardContext);
  var cardContentClassName = useClassName({
    style: CardContent$1,
    styleProps: _objectSpread2(_objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Card',
    themeKeySuffix: 'Content'
  });
  return /*#__PURE__*/createElement$1(Box$1, _extends({
    className: cardContentClassName,
    id: context.descriptionId
  }, restProps), children);
} /////////////////////////////////////

function CardTitle(props) {
  var children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["children"]);

  var context = useContext(CardContext);
  var cardTitleClassName = useClassName({
    style: CardTitle$1,
    styleProps: _objectSpread2(_objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Card',
    themeKeySuffix: 'Title'
  });
  return /*#__PURE__*/createElement$1(Box$1, _extends({
    className: cardTitleClassName,
    id: context.titleId
  }, restProps), children);
} /////////////////////////////////////

function CardHeader(props) {
  var children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["children"]);

  var context = useContext(CardContext);
  var cardHeaderClassName = useClassName({
    style: CardHeader$1,
    styleProps: _objectSpread2(_objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Card',
    themeKeySuffix: 'Header'
  });
  return /*#__PURE__*/createElement$1(Box$1, _extends({
    className: cardHeaderClassName
  }, restProps), children);
} /////////////////////////////////////

function CardFooter(props) {
  var children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["children"]);

  var context = useContext(CardContext);
  var cardFooterClassName = useClassName({
    style: CardFooter$1,
    styleProps: _objectSpread2(_objectSpread2({}, context), props),
    themeKey: context.themeKey || 'Card',
    themeKeySuffix: 'Footer'
  });
  return /*#__PURE__*/createElement$1(Box$1, _extends({
    className: cardFooterClassName
  }, restProps), children);
}

export { Card, CardContent, CardContext, CardFooter, CardHeader, CardTitle };
