import { useState, useEffect, useMemo, createElement, Fragment } from 'react';
import { FannypackThemeContext } from './ThemeContext.js';
import 'classnames';
import 'emotion';
import '@emotion/core';
import { ThemeProvider } from 'emotion-theming';
import '@emotion/styled';
import '../utils/useTheme.js';
import '../chunk-0c448560.js';
import 'lodash/kebabCase';
import 'tinycolor2';
import '../utils/isFunction.js';
import '../utils/get.js';
import '../utils/theme.js';
import '../utils/omit.js';
import '../utils/pick.js';
import '../utils/cssProps.js';
import '../utils/useLocalStorage.js';
import { Provider as Provider$1 } from './ColorModeContext.js';
import '../utils/useColorMode.js';
import '../utils/useStyle.js';
import '../utils/omitBy.js';
import '../utils/useDefaultProps.js';
import '../utils/useDebounce.js';
import 'lodash/uniq';
import '../utils/useClassName.js';
import '../utils/useBreakpoint.js';
import { IdProvider } from '../utils/uniqueId.js';
import '../utils/times.js';
import '../utils/parseIcons.js';
import '../utils/colors.js';
import '../utils/palette.js';
import '../utils/mergeRefs.js';
import 'deepmerge';
import 'lodash/set';
import '../utils/applyTheme.js';
import '../utils/bindFns.js';
import '../utils/createComponent.js';
import '../utils/createElement.js';
import '../utils/createHook.js';
import '../utils/forwardRefWithUse.js';
import '../utils/fieldAdaptors.js';
import '@emotion/is-prop-valid';
import '../utils/htmlProps.js';
import '../utils/OutsideClickHandler.js';
import '../theme/spacing.js';
import '../theme/palette.js';
import '../theme/modes.js';
import '../theme/altitudes.js';
import '../theme/borders.js';
import '../theme/borderRadii.js';
import '../theme/breakpoints.js';
import '../theme/global.js';
import '../theme/fonts.js';
import '../theme/fontWeights.js';
import '../theme/fontSizes.js';
import '../theme/Container.js';
import '@fortawesome/free-solid-svg-icons/faInfoCircle';
import '@fortawesome/free-solid-svg-icons/faChevronDown';
import '@fortawesome/free-solid-svg-icons/faChevronLeft';
import '@fortawesome/free-solid-svg-icons/faChevronRight';
import '@fortawesome/free-solid-svg-icons/faExclamationTriangle';
import '@fortawesome/free-solid-svg-icons/faCheckCircle';
import '@fortawesome/free-solid-svg-icons/faExclamationCircle';
import '@fortawesome/free-solid-svg-icons/faQuestionCircle';
import '@fortawesome/free-solid-svg-icons/faTimes';
import '@fortawesome/free-solid-svg-icons/faSearch';
import '@fortawesome/free-solid-svg-icons/faStar';
import '../theme/Icon.js';
import '../theme/Toast.js';
import buildTheme from '../theme/index.js';
import 'reakit';
import '../Button/styles-2cbff8a4.js';
import 'conditional-wrap';
import '../Box/styles-579aeb3a.js';
import { Box } from '../Box/Box.js';
import '../Flex/styles-7e4763fa.js';
import '../Flex/Flex.js';
import '../Icon/styles-749bc0cd.js';
import '../Icon/Icon.js';
import '../Text/styles-6d3156aa.js';
import '../Text/Text.js';
import '../Spinner/styles-7188f333.js';
import '../Spinner/Spinner.js';
import '../Button/Button.js';
import 'reakit/VisuallyHidden';
import '../Button/ButtonClose.js';
import '../Button/index.js';
import '../Alert/styles-6f88be80.js';
import '../Alert/Alert.js';
import '../Alert/index.js';
import '../Disclosure/styles-84dfb298.js';
import '../Disclosure/DisclosureState.js';
import '../Disclosure/Disclosure.js';
import '../Disclosure/DisclosureContent.js';
import '../Disclosure/index.js';
import '../Modal/styles-e07d4130.js';
import '../Modal/ModalState.js';
import '../Modal/ModalBackdrop.js';
import '../Modal/Modal.js';
import '../Modal/ModalDisclosure.js';
import '../Modal/index.js';
import '../Overlay/styles-ace1d618.js';
import '../Overlay/Overlay.js';
import '../Overlay/OverlayDisclosure.js';
import '../Overlay/OverlayState.js';
import '../Overlay/index.js';
import '../Drawer/styles-663901f1.js';
import '../Drawer/Drawer.js';
import '../Drawer/DrawerDisclosure.js';
import '../Drawer/DrawerState.js';
import '../Drawer/index.js';
import '../Stack/styles-c733d987.js';
import '../Stack/Stack.js';
import '../Page/styles-d191b307.js';
import { PageProvider } from '../Page/PageContext.js';
import '../Toast/styles-1bd7727f.js';
import '../Toast/Toast.js';
import { ToastProvider } from '../Toast/ToastContext.js';
import '../Toast/ToastManager.js';
import '../Toast/index.js';
import GlobalStyles from './GlobalStyles.js';

Provider.defaultProps = {
  colorMode: 'default'
};
function Provider(props) {
  var children = props.children,
      colorMode = props.colorMode,
      collapseBelow = props.collapseBelow,
      isStandalone = props.isStandalone,
      _theme = props.theme; ////////////////////////////////////////////////

  var _React$useState = useState(_theme),
      theme = _React$useState[0],
      setTheme = _React$useState[1];

  useEffect(function () {
    setTheme(_theme);
  }, [_theme]); ////////////////////////////////////////////////

  var derivedTheme = useMemo(function () {
    if (theme && isStandalone) {
      return theme;
    }

    return buildTheme(theme);
  }, [isStandalone, theme]); ////////////////////////////////////////////////

  var themeContextValue = useMemo(function () {
    return {
      theme: theme,
      setTheme: setTheme
    };
  }, [theme, setTheme]); ////////////////////////////////////////////////

  return /*#__PURE__*/createElement(FannypackThemeContext.Provider, {
    value: themeContextValue
  }, /*#__PURE__*/createElement(ThemeProvider, {
    theme: derivedTheme
  }, /*#__PURE__*/createElement(Provider$1, {
    mode: colorMode
  }, /*#__PURE__*/createElement(IdProvider, null, /*#__PURE__*/createElement(ToastProvider, null, /*#__PURE__*/createElement(PageProvider, {
    collapseBelow: collapseBelow
  }, /*#__PURE__*/createElement(Fragment, null, process.env.NODE_ENV !== 'test' && /*#__PURE__*/createElement(GlobalStyles, null), process.env.NODE_ENV === 'test' ? children : /*#__PURE__*/createElement(Box, null, children))))))));
}

export { Provider };
