'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
var uniqueId = require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('../theme/palette.js');
var reakit = require('reakit');
require('../Button/styles-8d59f6ca.js');
require('conditional-wrap');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Flex/styles-13231042.js');
require('../Flex/Flex.js');
require('../Icon/styles-ea974feb.js');
var Icon = require('../Icon/Icon.js');
require('../Text/styles-f1b322d0.js');
var Text = require('../Text/Text.js');
require('../Spinner/styles-67211e74.js');
require('../Spinner/Spinner.js');
require('../Button/Button.js');
require('reakit/VisuallyHidden');
require('../Button/ButtonClose.js');
var index = require('../Button/index.js');
require('../Card/styles-c4dd6f58.js');
require('../Card/Card.js');
var index$1 = require('../Card/index.js');
require('../Modal/styles-660b7886.js');
var styles = require('./styles-ceb0e563.js');
var ModalState = require('../Modal/ModalState.js');
require('../Modal/ModalBackdrop.js');
require('../Modal/Modal.js');
require('../Modal/ModalDisclosure.js');
require('../Modal/index.js');
require('../Overlay/styles-9cc855e1.js');
require('../Overlay/Overlay.js');
require('../Overlay/OverlayDisclosure.js');
require('../Overlay/OverlayState.js');
var index$3 = require('../Overlay/index.js');

var CalloutContext = React.createContext({});
var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var _props$closeButtonPro = props.closeButtonProps,
      closeButtonProps = _props$closeButtonPro === void 0 ? {} : _props$closeButtonPro,
      iconProps = props.iconProps,
      onClickClose = props.onClickClose,
      overrides = props.overrides,
      footer = props.footer,
      standalone = props.standalone,
      showCloseButton = props.showCloseButton,
      title = props.title,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["closeButtonProps", "iconProps", "onClickClose", "overrides", "footer", "standalone", "showCloseButton", "title"]);

  var cardProps = index$1.Card.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, restProps), {}, {
    standalone: true
  }));
  var className = useClassName.useClassName({
    style: styles.Callout,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: cardProps.className
  });
  var calloutCloseClassName = useClassName.useClassName({
    style: styles.CalloutClose,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Close',
    prevClassName: closeButtonProps.className
  });
  var titleId = uniqueId.useUniqueId('calloutTitle');
  var descriptionId = uniqueId.useUniqueId('calloutDescription');
  var context = React.useMemo(function () {
    return __chunk_1._objectSpread2({
      descriptionId: descriptionId,
      titleId: titleId
    }, props);
  }, [descriptionId, props, titleId]);
  var children = /*#__PURE__*/React.createElement(CalloutContext.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement(Box.Box, {
    display: "flex"
  }, standalone ? props.children : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(CalloutIcon, {
    iconProps: iconProps,
    overrides: overrides
  }), /*#__PURE__*/React.createElement(Box.Box, null, title && /*#__PURE__*/React.createElement(CalloutHeader, {
    overrides: overrides
  }, typeof title === 'string' ? /*#__PURE__*/React.createElement(CalloutTitle, {
    overrides: overrides
  }, title) : title), /*#__PURE__*/React.createElement(CalloutContent, {
    overrides: overrides
  }, props.children), footer && /*#__PURE__*/React.createElement(CalloutFooter, {
    overrides: overrides
  }, footer)))), showCloseButton && /*#__PURE__*/React.createElement(index.Button.Close, __chunk_1._extends({
    className: calloutCloseClassName,
    onClick: onClickClose,
    size: title ? undefined : 'small'
  }, closeButtonProps)));
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, cardProps), {}, {
    'aria-describedby': props.children ? descriptionId : undefined,
    'aria-labelledby': props.title ? titleId : undefined,
    className: className,
    children: children
  });
}, {
  defaultProps: {
    type: 'info'
  },
  themeKey: 'Callout'
});
var Callout = createComponent.createComponent(function (props) {
  var textProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: textProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Callout'
  },
  themeKey: 'Callout'
}); //////////////////////////////

var useCalloutContentProps = createHook.createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;
  var boxProps = Box.Box.useProps(props);
  var contextProps = React.useContext(CalloutContext);
  var className = useClassName.useClassName({
    style: styles.CalloutContent,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({
    id: props.id || contextProps.descriptionId
  }, boxProps), {}, {
    className: className
  });
}, {
  themeKey: 'Callout.Content'
});
var CalloutContent = createComponent.createComponent(function (props) {
  var calloutContentProps = useCalloutContentProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutContentProps
  });
}, {
  attach: {
    useProps: useCalloutContentProps,
    displayName: 'Callout.Content'
  },
  themeKey: 'Callout.Content'
}); //////////////////////////////

var useCalloutHeaderProps = createHook.createHook(function (props, _ref3) {
  var themeKey = _ref3.themeKey,
      themeKeyOverride = _ref3.themeKeyOverride;
  var boxProps = Box.Box.useProps(props);
  var contextProps = React.useContext(CalloutContext);
  var className = useClassName.useClassName({
    style: styles.CalloutHeader,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className
  });
}, {
  themeKey: 'Callout.Header'
});
var CalloutHeader = createComponent.createComponent(function (props) {
  var calloutHeaderProps = useCalloutHeaderProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutHeaderProps
  });
}, {
  attach: {
    useProps: useCalloutHeaderProps,
    displayName: 'Callout.Header'
  },
  themeKey: 'Callout.Header'
}); //////////////////////////////

var useCalloutTitleProps = createHook.createHook(function (props, _ref4) {
  var themeKey = _ref4.themeKey,
      themeKeyOverride = _ref4.themeKeyOverride;
  var textProps = Text.Text.useProps(props);
  var contextProps = React.useContext(CalloutContext);
  var className = useClassName.useClassName({
    style: styles.CalloutTitle,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: textProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({
    id: contextProps.titleId
  }, textProps), {}, {
    className: className
  });
}, {
  themeKey: 'Callout.Title'
});
var CalloutTitle = createComponent.createComponent(function (props) {
  var calloutTitleProps = useCalloutTitleProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutTitleProps
  });
}, {
  attach: {
    useProps: useCalloutTitleProps,
    displayName: 'Callout.Title'
  },
  defaultProps: {
    use: 'span'
  },
  themeKey: 'Callout.Title'
}); //////////////////////////////

var useCalloutFooterProps = createHook.createHook(function (props, _ref5) {
  var themeKey = _ref5.themeKey,
      themeKeyOverride = _ref5.themeKeyOverride;
  var boxProps = Box.Box.useProps(props);
  var contextProps = React.useContext(CalloutContext);
  var className = useClassName.useClassName({
    style: styles.CalloutFooter,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className
  });
}, {
  themeKey: 'Callout.Footer'
});
var CalloutFooter = createComponent.createComponent(function (props) {
  var calloutFooterProps = useCalloutFooterProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutFooterProps
  });
}, {
  attach: {
    useProps: useCalloutFooterProps,
    displayName: 'Callout.Footer'
  },
  themeKey: 'Callout.Footer'
}); //////////////////////////////

var useCalloutIconProps = createHook.createHook(function (props, _ref6) {
  var themeKey = _ref6.themeKey,
      themeKeyOverride = _ref6.themeKeyOverride;

  var iconProps = props.iconProps,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["iconProps"]);

  var boxProps = Box.Box.useProps(restProps);
  var contextProps = React.useContext(CalloutContext);
  var className = useClassName.useClassName({
    style: styles.CalloutIconWrapper,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var icon = /*#__PURE__*/React.createElement(Icon.Icon, __chunk_1._extends({
    "aria-hidden": true,
    color: contextProps.type,
    fontSize: !contextProps.title ? '300' : undefined,
    icon: contextProps.type
  }, iconProps));
  var children = /*#__PURE__*/React.createElement(CalloutContent, {
    id: undefined
  }, icon);

  if (contextProps.title) {
    children = /*#__PURE__*/React.createElement(CalloutHeader, null, /*#__PURE__*/React.createElement(CalloutTitle, {
      id: undefined
    }, icon));
  }

  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    children: children
  });
}, {
  themeKey: 'Callout.IconWrapper'
});
var CalloutIcon = createComponent.createComponent(function (props) {
  var calloutIconProps = useCalloutIconProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutIconProps
  });
}, {
  attach: {
    useProps: useCalloutIconProps,
    displayName: 'Callout.IconWrapper'
  },
  themeKey: 'Callout.IconWrapper'
}); //////////////////////////////

var useCalloutOverlayProps = createHook.createHook(function (props, _ref7) {
  var themeKey = _ref7.themeKey,
      themeKeyOverride = _ref7.themeKeyOverride;

  var variant = props.variant,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["variant"]);

  var _React$useContext = React.useContext(ModalState.ModalContext),
      modal = _React$useContext.modal;

  var calloutProps = Callout.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({
    onClickClose: restProps.hide || modal.hide
  }, restProps), {}, {
    wrapElement: function wrapElement(children) {
      return (
        /*#__PURE__*/
        // @ts-ignore
        React.createElement(index$3.Overlay, __chunk_1._extends({
          placement: "bottom-end"
        }, restProps), children)
      );
    }
  }));
  var contextProps = React.useContext(CalloutContext);
  var className = useClassName.useClassName({
    style: styles.CalloutOverlay,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: calloutProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, calloutProps), {}, {
    className: className
  });
}, {
  defaultProps: {
    showCloseButton: true
  },
  themeKey: 'Callout.Overlay'
});
var CalloutOverlay = createComponent.createComponent(function (props) {
  var calloutOverlayProps = useCalloutOverlayProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutOverlayProps
  });
}, {
  attach: {
    useProps: useCalloutOverlayProps,
    displayName: 'Callout.Overlay'
  },
  themeKey: 'Callout.Overlay'
});

exports.Callout = Callout;
exports.CalloutContent = CalloutContent;
exports.CalloutContext = CalloutContext;
exports.CalloutFooter = CalloutFooter;
exports.CalloutHeader = CalloutHeader;
exports.CalloutIcon = CalloutIcon;
exports.CalloutOverlay = CalloutOverlay;
exports.CalloutTitle = CalloutTitle;
