'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
var omit = require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
var uniqueId = require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('../utils/getHiddenInputStyles.js');
require('../theme/palette.js');
var reakit = require('reakit');
require('../Button/styles-8d59f6ca.js');
require('conditional-wrap');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Flex/styles-13231042.js');
require('../Flex/Flex.js');
require('../Icon/styles-ea974feb.js');
require('../Icon/Icon.js');
require('../Text/styles-f1b322d0.js');
require('../Text/Text.js');
require('../Spinner/styles-67211e74.js');
require('../Spinner/Spinner.js');
require('../Button/Button.js');
require('reakit/VisuallyHidden');
require('../Button/ButtonClose.js');
require('../Button/index.js');
require('../FieldWrapper/styles-5947956c.js');
require('../Card/styles-c4dd6f58.js');
require('../Card/Card.js');
require('../Card/index.js');
require('../Disclosure/styles-c34e6c23.js');
require('../Disclosure/DisclosureState.js');
require('../Disclosure/Disclosure.js');
require('../Disclosure/DisclosureContent.js');
require('../Disclosure/index.js');
require('../Label/styles-75351763.js');
var Label = require('../Label/Label.js');
var FieldWrapper = require('../FieldWrapper/FieldWrapper.js');
var styles = require('./styles-15a9f6bf.js');

var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var autoFocus = props.autoFocus,
      checked = props.checked,
      checkboxRef = props.checkboxRef,
      inputProps = props.inputProps,
      defaultChecked = props.defaultChecked,
      disabled = props.disabled,
      indeterminate = props.indeterminate,
      isRequired = props.isRequired,
      label = props.label,
      name = props.name,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onFocus = props.onFocus,
      state = props.state,
      value = props.value,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["autoFocus", "checked", "checkboxRef", "inputProps", "defaultChecked", "disabled", "indeterminate", "isRequired", "label", "name", "onBlur", "onChange", "onFocus", "state", "value"]);

  var boxProps = Box.Box.useProps(restProps);
  var className = useClassName.useClassName({
    style: styles.Checkbox,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var checkboxIconClassName = useClassName.useClassName({
    style: styles.CheckboxIcon,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Icon'
  });
  var hiddenCheckboxClassName = useClassName.useClassName({
    style: styles.HiddenCheckbox,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'HiddenInput'
  });
  var checkboxLabelClassName = useClassName.useClassName({
    style: styles.CheckboxLabel,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Label'
  });
  var labelId = uniqueId.useUniqueId('label');
  var checkboxId = uniqueId.useUniqueId('checkbox');
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    'aria-describedby': labelId,
    'aria-invalid': state === 'danger',
    'aria-required': isRequired,
    className: className,
    children: /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
      ref: checkboxRef,
      use: "input",
      className: hiddenCheckboxClassName // @ts-ignore
      ,
      autoFocus: autoFocus,
      checked: checked,
      defaultChecked: defaultChecked,
      disabled: disabled,
      id: checkboxId // @ts-ignore
      ,
      indeterminate: indeterminate,
      onBlur: onBlur,
      onChange: onChange,
      onFocus: onFocus,
      name: name,
      type: "checkbox" // @ts-ignore
      ,
      value: value
    }, inputProps)), /*#__PURE__*/React.createElement(Box.Box, {
      className: checkboxIconClassName
    }), label && /*#__PURE__*/React.createElement(Label.Label, {
      use: "span",
      id: labelId,
      className: checkboxLabelClassName,
      htmlFor: checkboxId,
      marginLeft: "minor-2"
    }, label))
  });
}, {
  themeKey: 'Checkbox'
});
var Checkbox = createComponent.createComponent(function (props) {
  var textProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: textProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Checkbox'
  },
  defaultProps: {
    use: Label.Label
  },
  themeKey: 'Checkbox'
}); ////////////////////////////////////////////////////////////////

var useCheckboxFieldProps = createHook.createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;

  var autoFocus = props.autoFocus,
      checked = props.checked,
      checkboxLabel = props.checkboxLabel,
      checkboxProps = props.checkboxProps,
      checkboxRef = props.checkboxRef,
      description = props.description,
      defaultChecked = props.defaultChecked,
      disabled = props.disabled,
      hint = props.hint,
      indeterminate = props.indeterminate,
      isOptional = props.isOptional,
      isRequired = props.isRequired,
      label = props.label,
      name = props.name,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onFocus = props.onFocus,
      overrides = props.overrides,
      state = props.state,
      tooltip = props.tooltip,
      tooltipTriggerComponent = props.tooltipTriggerComponent,
      validationText = props.validationText,
      value = props.value,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["autoFocus", "checked", "checkboxLabel", "checkboxProps", "checkboxRef", "description", "defaultChecked", "disabled", "hint", "indeterminate", "isOptional", "isRequired", "label", "name", "onBlur", "onChange", "onFocus", "overrides", "state", "tooltip", "tooltipTriggerComponent", "validationText", "value"]);

  var boxProps = Box.Box.useProps(restProps);
  var className = useClassName.useClassName({
    style: styles.CheckboxField,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    children: /*#__PURE__*/React.createElement(FieldWrapper.FieldWrapper, {
      description: description,
      hint: hint,
      isOptional: isOptional,
      isRequired: isRequired,
      label: label,
      labelType: "legend",
      overrides: overrides,
      state: state,
      tooltip: tooltip,
      tooltipTriggerComponent: tooltipTriggerComponent,
      validationText: validationText
    }, function (_ref3) {
      var elementProps = _ref3.elementProps;
      return /*#__PURE__*/React.createElement(Checkbox, __chunk_1._extends({
        autoFocus: autoFocus,
        checked: checked,
        defaultChecked: defaultChecked,
        disabled: disabled,
        checkboxRef: checkboxRef,
        indeterminate: indeterminate,
        isRequired: isRequired,
        label: checkboxLabel,
        name: name,
        onBlur: onBlur,
        onChange: onChange,
        onFocus: onFocus,
        overrides: overrides,
        state: state,
        value: value
      }, omit.omit(elementProps, 'id'), checkboxProps, {
        inputProps: __chunk_1._objectSpread2({
          id: elementProps.id
        }, checkboxProps.inputProps)
      }));
    })
  });
}, {
  defaultProps: {
    checkboxProps: {}
  },
  themeKey: 'CheckboxField'
});
var CheckboxField = createComponent.createComponent(function (props) {
  var checkboxFieldProps = useCheckboxFieldProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: checkboxFieldProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'CheckboxField'
  },
  themeKey: 'CheckboxField'
});

exports.Checkbox = Checkbox;
exports.CheckboxField = CheckboxField;
