'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
var cssProps = require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
var uniqueId = require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
var bindFns = require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('../theme/palette.js');
require('../ActionButtons/styles-b19d93e0.js');
var reakit = require('reakit');
require('../Button/styles-8d59f6ca.js');
require('conditional-wrap');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Flex/styles-13231042.js');
require('../Flex/Flex.js');
require('../Icon/styles-ea974feb.js');
var Icon = require('../Icon/Icon.js');
require('../Text/styles-f1b322d0.js');
var Text = require('../Text/Text.js');
require('../Spinner/styles-67211e74.js');
require('../Spinner/Spinner.js');
require('../Button/Button.js');
require('reakit/VisuallyHidden');
require('../Button/ButtonClose.js');
var index = require('../Button/index.js');
require('../Set/styles-f69d4775.js');
require('../Set/Set.js');
var ActionButtons = require('../ActionButtons/ActionButtons.js');
require('../Modal/styles-660b7886.js');
var ModalState = require('../Modal/ModalState.js');
require('../Modal/ModalBackdrop.js');
require('../Modal/Modal.js');
require('../Modal/ModalDisclosure.js');
var index$2 = require('../Modal/index.js');
var styles$3 = require('./styles-d863f205.js');

var DialogContext = React.createContext({});
var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var _props$actionButtonsP = props.actionButtonsProps,
      actionButtonsProps = _props$actionButtonsP === void 0 ? {} : _props$actionButtonsP,
      _props$closeButtonPro = props.closeButtonProps,
      closeButtonProps = _props$closeButtonPro === void 0 ? {} : _props$closeButtonPro,
      footer = props.footer,
      _props$iconProps = props.iconProps,
      iconProps = _props$iconProps === void 0 ? {} : _props$iconProps,
      onClickClose = props.onClickClose,
      overrides = props.overrides,
      palette = props.palette,
      showActionButtons = props.showActionButtons,
      showCloseButton = props.showCloseButton,
      standalone = props.standalone,
      title = props.title,
      type = props.type,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["actionButtonsProps", "closeButtonProps", "footer", "iconProps", "onClickClose", "overrides", "palette", "showActionButtons", "showCloseButton", "standalone", "title", "type"]);

  var boxProps = Box.Box.useProps(restProps);
  var className = useClassName.useClassName({
    style: styles$3.Dialog,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var dialogCloseClassName = useClassName.useClassName({
    style: styles$3.DialogClose,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Close',
    prevClassName: closeButtonProps.className
  });
  var titleId = uniqueId.useUniqueId('dialogTitle');
  var descriptionId = uniqueId.useUniqueId('dialogDescription');
  var context = React.useMemo(function () {
    return __chunk_1._objectSpread2({
      descriptionId: descriptionId,
      titleId: titleId
    }, props);
  }, [descriptionId, props, titleId]);
  var children = /*#__PURE__*/React.createElement(DialogContext.Provider, {
    value: context
  }, standalone ? props.children : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(DialogContent, {
    overrides: overrides
  }, type && /*#__PURE__*/React.createElement(DialogIcon, {
    iconProps: iconProps,
    overrides: overrides
  }), /*#__PURE__*/React.createElement(Box.Box, {
    width: "100%"
  }, title && /*#__PURE__*/React.createElement(DialogHeader, {
    overrides: overrides
  }, typeof title === 'string' ? /*#__PURE__*/React.createElement(DialogTitle, {
    overrides: overrides
  }, title) : title, showCloseButton && /*#__PURE__*/React.createElement(index.Button.Close, __chunk_1._extends({
    className: dialogCloseClassName,
    onClick: onClickClose,
    size: title ? undefined : 'small'
  }, closeButtonProps))), props.children)), (footer || showActionButtons) && /*#__PURE__*/React.createElement(DialogFooter, {
    overrides: overrides
  }, footer && /*#__PURE__*/React.createElement(Box.Box, null, footer), showActionButtons && /*#__PURE__*/React.createElement(Box.Box, null, /*#__PURE__*/React.createElement(ActionButtons.ActionButtons, __chunk_1._extends({
    palette: palette
  }, actionButtonsProps))))));
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({
    'aria-describedby': props.children ? descriptionId : undefined,
    'aria-labelledby': props.title ? titleId : undefined
  }, boxProps), {}, {
    className: className,
    children: children
  });
}, {
  themeKey: 'Dialog'
});
var Dialog = createComponent.createComponent(function (props) {
  var dialogProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: dialogProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Dialog'
  },
  themeKey: 'Dialog'
}); //////////////////////////////

var useDialogContentProps = createHook.createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;
  var boxProps = Box.Box.useProps(props);
  var contextProps = React.useContext(DialogContext);
  var className = useClassName.useClassName({
    style: styles$3.DialogContent,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({
    id: props.id || contextProps.descriptionId
  }, boxProps), {}, {
    className: className
  });
}, {
  themeKey: 'Dialog.Content'
});
var DialogContent = createComponent.createComponent(function (props) {
  var calloutContentProps = useDialogContentProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutContentProps
  });
}, {
  attach: {
    useProps: useDialogContentProps,
    displayName: 'Dialog.Content'
  },
  themeKey: 'Dialog.Content'
}); //////////////////////////////

var useDialogHeaderProps = createHook.createHook(function (props, _ref3) {
  var themeKey = _ref3.themeKey,
      themeKeyOverride = _ref3.themeKeyOverride;
  var boxProps = Box.Box.useProps(props);
  var contextProps = React.useContext(DialogContext);
  var className = useClassName.useClassName({
    style: styles$3.DialogHeader,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className
  });
}, {
  themeKey: 'Dialog.Header'
});
var DialogHeader = createComponent.createComponent(function (props) {
  var calloutHeaderProps = useDialogHeaderProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutHeaderProps
  });
}, {
  attach: {
    useProps: useDialogHeaderProps,
    displayName: 'Dialog.Header'
  },
  themeKey: 'Dialog.Header'
}); //////////////////////////////

var useDialogTitleProps = createHook.createHook(function (props, _ref4) {
  var themeKey = _ref4.themeKey,
      themeKeyOverride = _ref4.themeKeyOverride;
  var textProps = Text.Text.useProps(props);
  var contextProps = React.useContext(DialogContext);
  var className = useClassName.useClassName({
    style: styles$3.DialogTitle,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: textProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({
    id: contextProps.titleId
  }, textProps), {}, {
    className: className
  });
}, {
  themeKey: 'Dialog.Title'
});
var DialogTitle = createComponent.createComponent(function (props) {
  var calloutTitleProps = useDialogTitleProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutTitleProps
  });
}, {
  attach: {
    useProps: useDialogTitleProps,
    displayName: 'Dialog.Title'
  },
  defaultProps: {
    use: 'span'
  },
  themeKey: 'Dialog.Title'
}); //////////////////////////////

var useDialogFooterProps = createHook.createHook(function (props, _ref5) {
  var themeKey = _ref5.themeKey,
      themeKeyOverride = _ref5.themeKeyOverride;
  var boxProps = Box.Box.useProps(props);
  var contextProps = React.useContext(DialogContext);
  var className = useClassName.useClassName({
    style: styles$3.DialogFooter,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className
  });
}, {
  themeKey: 'Dialog.Footer'
});
var DialogFooter = createComponent.createComponent(function (props) {
  var calloutFooterProps = useDialogFooterProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: calloutFooterProps
  });
}, {
  attach: {
    useProps: useDialogFooterProps,
    displayName: 'Dialog.Footer'
  },
  themeKey: 'Dialog.Footer'
}); //////////////////////////////

var useDialogIconProps = createHook.createHook(function (props, _ref6) {
  var themeKey = _ref6.themeKey,
      themeKeyOverride = _ref6.themeKeyOverride;

  var iconProps = props.iconProps,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["iconProps"]);

  var textProps = Text.Text.useProps(restProps);
  var contextProps = React.useContext(DialogContext);
  var className = useClassName.useClassName({
    style: styles$3.DialogIconWrapper,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: textProps.className
  });
  var icon = /*#__PURE__*/React.createElement(Icon.Icon, __chunk_1._extends({
    "aria-hidden": true,
    color: contextProps.type,
    fontSize: !contextProps.title ? '300' : undefined,
    icon: contextProps.type
  }, iconProps));
  var children = icon;

  if (contextProps.title) {
    children = /*#__PURE__*/React.createElement(DialogHeader, null, /*#__PURE__*/React.createElement(DialogTitle, {
      id: undefined
    }, icon));
  }

  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, textProps), {}, {
    className: className,
    children: children
  });
}, {
  themeKey: 'Dialog.IconWrapper'
});
var DialogIcon = createComponent.createComponent(function (props) {
  var DialogIconProps = useDialogIconProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: DialogIconProps
  });
}, {
  attach: {
    useProps: useDialogIconProps,
    displayName: 'Dialog.IconWrapper'
  },
  defaultProps: {
    use: 'span'
  },
  themeKey: 'Dialog.IconWrapper'
}); //////////////////////////////

var useDialogModalProps = createHook.createHook(function (props, _ref7) {
  var _restProps$actionButt;

  var themeKey = _ref7.themeKey,
      themeKeyOverride = _ref7.themeKeyOverride;

  var _React$useContext = React.useContext(ModalState.ModalContext),
      modal = _React$useContext.modal;

  var _modal$props = __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, modal), props),
      variant = _modal$props.variant,
      restProps = __chunk_1._objectWithoutPropertiesLoose(_modal$props, ["variant"]);

  var dialogProps = Dialog.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, restProps), {}, {
    onClickClose: bindFns.bindFns(restProps.hide, props.onClickClose),
    actionButtonsProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, restProps.actionButtonsProps), {}, {
      onClickCancel: bindFns.bindFns(restProps.hide, (_restProps$actionButt = restProps.actionButtonsProps) === null || _restProps$actionButt === void 0 ? void 0 : _restProps$actionButt.onClickCancel)
    }),
    wrapElement: function wrapElement(children) {
      return (
        /*#__PURE__*/
        // @ts-ignore
        React.createElement(index$2.Modal, __chunk_1._extends({
          hideOnEsc: variant !== 'alert',
          hideOnClickOutside: variant !== 'alert',
          role: variant === 'alert' ? 'alertdialog' : 'dialog'
        }, cssProps.omitCSSProps(restProps)), children)
      );
    }
  }));
  var contextProps = React.useContext(DialogContext);
  var className = useClassName.useClassName({
    style: styles$3.DialogModal,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, contextProps), props),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: dialogProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, dialogProps), {}, {
    className: className
  });
}, {
  defaultProps: {
    hasScroll: true
  },
  themeKey: 'Dialog.Modal'
});
var DialogModal = createComponent.createComponent(function (props) {
  var DialogModalProps = useDialogModalProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: DialogModalProps
  });
}, {
  attach: {
    useProps: useDialogModalProps,
    displayName: 'Dialog.Modal'
  },
  themeKey: 'Dialog.Modal'
});

exports.Dialog = Dialog;
exports.DialogContent = DialogContent;
exports.DialogContext = DialogContext;
exports.DialogFooter = DialogFooter;
exports.DialogHeader = DialogHeader;
exports.DialogIcon = DialogIcon;
exports.DialogModal = DialogModal;
exports.DialogTitle = DialogTitle;
