'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
require('../utils/uniqueId.js');
var times = require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
var reakit = require('reakit');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Icon/styles-ea974feb.js');
var Icon$1 = require('../Icon/Icon.js');
require('../Rover/styles-a9cd5716.js');
require('../Rover/RoverState.js');
require('../Rover/Rover.js');
var index = require('../Rover/index.js');
var styles$1 = require('./styles-68bbc695.js');

var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var color = props.color,
      item = props.item,
      items = props.items,
      isSingular = props.isSingular,
      isStatic = props.isStatic,
      onChange = props.onChange,
      overrides = props.overrides,
      maxValue = props.maxValue,
      roverProps = props.roverProps,
      size = props.size,
      value = props.value,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["color", "item", "items", "isSingular", "isStatic", "onChange", "overrides", "maxValue", "roverProps", "size", "value"]);

  var boxProps = Box.Box.useProps(restProps);
  var rover = index.Rover.useState();

  var _React$useState = React.useState(-1),
      hoveringIndex = _React$useState[0],
      setHoveringIndex = _React$useState[1];

  var className = useClassName.useClassName({
    style: styles$1.Rating,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  var disabled = props.disabled || isStatic;
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    onMouseLeave: !disabled ? function () {
      return setHoveringIndex(-1);
    } : undefined,
    overrides: overrides,
    role: 'radiogroup',
    children: times.times(items ? items.length : maxValue, function (index$1) {
      return /*#__PURE__*/React.createElement(index.Rover, __chunk_1._extends({}, rover, roverProps, {
        disabled: disabled
      }), function (props) {
        return (
          /*#__PURE__*/

          /*
          // @ts-ignore */
          React.createElement(RatingItem, __chunk_1._extends({
            key: index$1
          }, props, {
            "aria-checked": value === index$1 + 1,
            "aria-posinset": index$1 + 1,
            "aria-setsize": maxValue,
            color: color,
            isActive: hoveringIndex >= 0 ? isSingular ? hoveringIndex === index$1 : hoveringIndex >= index$1 : isSingular ? value === index$1 + 1 : value > index$1,
            isStatic: isStatic,
            onClick: !disabled ? function () {
              return onChange(index$1 + 1);
            } : undefined,
            onMouseEnter: !disabled ? function () {
              return setHoveringIndex(index$1);
            } : undefined,
            overrides: overrides,
            size: size
          }), item || (items === null || items === void 0 ? void 0 : items[index$1]))
        );
      });
    })
  });
}, {
  defaultProps: {
    maxValue: 5,
    value: 0
  },
  themeKey: 'Rating'
});
var Rating = createComponent.createComponent(function (props) {
  var ratingProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: ratingProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Rating'
  },
  themeKey: 'Rating'
}); ////////////////////////////////////////

var useRatingItemProps = createHook.createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;

  var children = props.children,
      color = props.color,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children", "color"]);

  var boxProps = Box.Box.useProps(restProps);
  var className = useClassName.useClassName({
    style: styles$1.RatingItem,
    styleProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, props), {}, {
      color: color
    }),
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    role: 'radio',
    children: children
  });
}, {
  defaultProps: {
    children: /*#__PURE__*/React.createElement(Icon$1.Icon, {
      icon: "star"
    }),
    color: 'gold'
  },
  themeKey: 'Rating.Item'
});
var RatingItem = createComponent.createComponent(function (props) {
  var ratingItemProps = useRatingItemProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: ratingItemProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Rating.Item'
  },
  themeKey: 'Rating.Item'
});

exports.Rating = Rating;
exports.RatingItem = RatingItem;
