'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
var cssProps = require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
require('../theme/palette.js');
var reakit = require('reakit');
require('../Button/styles-8d59f6ca.js');
require('conditional-wrap');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Flex/styles-13231042.js');
require('../Flex/Flex.js');
require('../Icon/styles-ea974feb.js');
require('../Icon/Icon.js');
require('../Text/styles-f1b322d0.js');
require('../Text/Text.js');
require('../Spinner/styles-67211e74.js');
require('../Spinner/Spinner.js');
require('../Button/Button.js');
require('reakit/VisuallyHidden');
require('../Button/ButtonClose.js');
require('../Button/index.js');
require('../FieldWrapper/styles-5947956c.js');
require('../Card/styles-c4dd6f58.js');
require('../Card/Card.js');
require('../Card/index.js');
require('../Disclosure/styles-c34e6c23.js');
require('../Disclosure/DisclosureState.js');
require('../Disclosure/Disclosure.js');
require('../Disclosure/DisclosureContent.js');
require('../Disclosure/index.js');
require('../Label/styles-75351763.js');
require('../Label/Label.js');
var FieldWrapper = require('../FieldWrapper/FieldWrapper.js');
var styles = require('./styles-1b275aa7.js');

var useProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var isRequired = props.isRequired,
      state = props.state,
      textareaRef = props.textareaRef,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["isRequired", "state", "textareaRef"]);

  var wrapperClassName = useClassName.useClassName({
    style: styles.TextareaWrapper,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    themeKeySuffix: 'Wrapper',
    prevClassName: restProps.className
  });
  var boxProps = Box.Box.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, cssProps.omitCSSProps(restProps)), {}, {
    className: undefined,
    elementRef: textareaRef || props.elementRef,
    wrapElement: function wrapElement(children) {
      return /*#__PURE__*/React.createElement(Box.Box, __chunk_1._extends({
        className: wrapperClassName
      }, cssProps.pickCSSProps(props)), children);
    }
  }));
  var className = useClassName.useClassName({
    style: styles.Textarea,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    'aria-invalid': state === 'danger',
    'aria-required': isRequired
  });
}, {
  defaultProps: {
    type: 'text'
  },
  themeKey: 'Textarea'
});
var Textarea = createComponent.createComponent(function (props) {
  var textareaProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, textareaProps), props.mask ? {
      mask: props.mask
    } : {})
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Textarea'
  },
  defaultProps: {
    use: 'textarea'
  },
  themeKey: 'Textarea'
}); ////////////////////////////////////////////////////////////////

var useTextareaFieldProps = createHook.createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;

  var children = props.children,
      autoComplete = props.autoComplete,
      autoFocus = props.autoFocus,
      defaultValue = props.defaultValue,
      description = props.description,
      disabled = props.disabled,
      hint = props.hint,
      textareaProps = props.textareaProps,
      isOptional = props.isOptional,
      isRequired = props.isRequired,
      label = props.label,
      name = props.name,
      size = props.size,
      mask = props.mask,
      maxLength = props.maxLength,
      minLength = props.minLength,
      multiple = props.multiple,
      pattern = props.pattern,
      placeholder = props.placeholder,
      readOnly = props.readOnly,
      spellCheck = props.spellCheck,
      step = props.step,
      state = props.state,
      tooltip = props.tooltip,
      tooltipTriggerComponent = props.tooltipTriggerComponent,
      type = props.type,
      value = props.value,
      onBlur = props.onBlur,
      onChange = props.onChange,
      onFocus = props.onFocus,
      overrides = props.overrides,
      textareaRef = props.textareaRef,
      validationText = props.validationText,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["children", "autoComplete", "autoFocus", "defaultValue", "description", "disabled", "hint", "textareaProps", "isOptional", "isRequired", "label", "name", "size", "mask", "maxLength", "minLength", "multiple", "pattern", "placeholder", "readOnly", "spellCheck", "step", "state", "tooltip", "tooltipTriggerComponent", "type", "value", "onBlur", "onChange", "onFocus", "overrides", "textareaRef", "validationText"]);

  var boxProps = Box.Box.useProps(restProps);
  var className = useClassName.useClassName({
    style: styles.TextareaField,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    children: /*#__PURE__*/React.createElement(FieldWrapper.FieldWrapper, {
      description: description,
      hint: hint,
      isOptional: isOptional,
      isRequired: isRequired,
      label: label,
      overrides: overrides,
      state: state,
      tooltip: tooltip,
      tooltipTriggerComponent: tooltipTriggerComponent,
      validationText: validationText
    }, function (_ref3) {
      var elementProps = _ref3.elementProps;
      return /*#__PURE__*/React.createElement(Textarea, __chunk_1._extends({
        autoComplete: autoComplete,
        autoFocus: autoFocus,
        defaultValue: defaultValue,
        disabled: disabled,
        isRequired: isRequired,
        name: name,
        size: size,
        mask: mask,
        maxLength: maxLength,
        minLength: minLength,
        multiple: multiple,
        pattern: pattern,
        placeholder: placeholder,
        readOnly: readOnly,
        spellCheck: spellCheck,
        step: step,
        state: state,
        type: type,
        value: value,
        onBlur: onBlur,
        onChange: onChange,
        onFocus: onFocus,
        overrides: overrides,
        textareaRef: textareaRef
      }, elementProps, textareaProps));
    })
  });
}, {
  themeKey: 'TextareaField'
});
var TextareaField = createComponent.createComponent(function (props) {
  var textareaFieldProps = useTextareaFieldProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: textareaFieldProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'TextareaField'
  },
  themeKey: 'TextareaField'
});

exports.Textarea = Textarea;
exports.TextareaField = TextareaField;
