'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
require('../Provider/ThemeContext.js');
require('classnames');
require('emotion');
require('@emotion/core');
require('emotion-theming');
require('@emotion/styled');
require('../utils/useTheme.js');
var __chunk_1 = require('../chunk-4f52fe58.js');
require('lodash/kebabCase');
require('tinycolor2');
require('../utils/isFunction.js');
require('../utils/get.js');
require('../utils/theme.js');
require('../utils/omit.js');
require('../utils/pick.js');
require('../utils/cssProps.js');
require('../utils/useLocalStorage.js');
require('../Provider/ColorModeContext.js');
require('../utils/useColorMode.js');
require('../utils/useStyle.js');
require('../utils/omitBy.js');
require('../utils/useDefaultProps.js');
require('../utils/useDebounce.js');
require('lodash/uniq');
var useClassName = require('../utils/useClassName.js');
require('../utils/useBreakpoint.js');
require('../utils/uniqueId.js');
require('../utils/times.js');
require('../utils/parseIcons.js');
require('../utils/colors.js');
require('../utils/palette.js');
require('../utils/mergeRefs.js');
require('deepmerge');
require('lodash/set');
require('../utils/applyTheme.js');
require('../utils/bindFns.js');
var createComponent = require('../utils/createComponent.js');
var createElement = require('../utils/createElement.js');
var createHook = require('../utils/createHook.js');
require('../utils/forwardRefWithUse.js');
require('../utils/fieldAdaptors.js');
require('@emotion/is-prop-valid');
require('../utils/htmlProps.js');
require('../utils/OutsideClickHandler.js');
var reakit = require('reakit');
require('../Box/styles-efc98bd0.js');
var Box = require('../Box/Box.js');
require('../Modal/styles-660b7886.js');
var styles = require('./styles-bf6fd5df.js');
var TooltipState = require('./TooltipState.js');

var useProps = createHook.createHook(function (props) {
  var arrowProps = props.arrowProps,
      children = props.children,
      content = props.content,
      expand = props.expand,
      fade = props.fade,
      hasArrow = props.hasArrow,
      overrides = props.overrides,
      placement = props.placement,
      slide = props.slide,
      baseId = props.baseId;
  var boxProps = Box.Box.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, props), {}, {
    content: undefined
  })); // @ts-ignore

  var tooltip = TooltipState.useTooltipState({
    placement: placement,
    animated: expand || fade || slide,
    baseId: baseId
  });
  return {
    children: /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TooltipReference, __chunk_1._extends({
      overrides: overrides
    }, boxProps, tooltip), React.isValidElement(children) ?
    /*
    // @ts-ignore */
    function (referenceProps) {
      return React.cloneElement(children, __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, referenceProps), children.props));
    } : children), /*#__PURE__*/React.createElement(TooltipContent, __chunk_1._extends({
      arrowProps: arrowProps,
      expand: expand,
      fade: fade,
      hasArrow: hasArrow,
      overrides: overrides,
      slide: slide
    }, tooltip), content))
  };
}, {
  themeKey: 'Tooltip',
  defaultProps: {
    placement: 'top'
  }
});
var Tooltip = createComponent.createComponent(function (props) {
  var tooltipProps = useProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: tooltipProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Tooltip'
  },
  themeKey: 'Tooltip'
}); ////////////////////////////////////////////////////////////

var useTooltipContentProps = createHook.createHook(function (props, _ref) {
  var themeKey = _ref.themeKey,
      themeKeyOverride = _ref.themeKeyOverride;

  var arrowProps = props.arrowProps,
      children = props.children,
      hasArrow = props.hasArrow,
      overrides = props.overrides,
      visible = props.visible,
      baseId = props.baseId,
      animating = props.animating,
      animated = props.animated,
      unstable_popoverRef = props.unstable_popoverRef,
      unstable_popoverStyles = props.unstable_popoverStyles,
      unstable_portal = props.unstable_portal,
      stopAnimation = props.stopAnimation,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["arrowProps", "children", "hasArrow", "overrides", "visible", "baseId", "animating", "animated", "unstable_popoverRef", "unstable_popoverStyles", "unstable_portal", "stopAnimation"]);

  var tooltipProps = reakit.useTooltip({
    visible: visible,
    baseId: baseId,
    animating: animating,
    animated: animated,
    unstable_popoverRef: unstable_popoverRef,
    unstable_popoverStyles: unstable_popoverStyles,
    unstable_portal: unstable_portal,
    stopAnimation: stopAnimation
  }, restProps);
  var boxProps = Box.Box.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, props), tooltipProps));
  var className = useClassName.useClassName({
    style: styles.TooltipContent,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className,
    children: /*#__PURE__*/React.createElement(React.Fragment, null, hasArrow && /*#__PURE__*/React.createElement(TooltipArrow, __chunk_1._extends({
      overrides: overrides // @ts-ignore
      ,
      placement: props.placement // @ts-ignore
      ,
      unstable_arrowRef: props.unstable_arrowRef // @ts-ignore
      ,
      unstable_arrowStyles: props.unstable_arrowStyles
    }, arrowProps)), children)
  });
}, {
  themeKey: 'Tooltip.Content'
});
var TooltipContent = createComponent.createComponent(function (props) {
  var tooltipContentProps = useTooltipContentProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: tooltipContentProps
  });
}, {
  attach: {
    useProps: useProps,
    displayName: 'Tooltip.Content'
  },
  themeKey: 'Tooltip.Content'
}); ////////////////////////////////////////////////////////////

var useTooltipReferenceProps = createHook.createHook(function (props, _ref2) {
  var themeKey = _ref2.themeKey,
      themeKeyOverride = _ref2.themeKeyOverride;

  var show = props.show,
      hide = props.hide,
      unstable_referenceRef = props.unstable_referenceRef,
      baseId = props.baseId,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["show", "hide", "unstable_referenceRef", "baseId"]);

  var tooltipReferenceProps = reakit.useTooltipReference({
    show: show,
    hide: hide,
    unstable_referenceRef: unstable_referenceRef,
    baseId: baseId
  }, restProps);
  var boxProps = Box.Box.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, props), tooltipReferenceProps));
  var className = useClassName.useClassName({
    style: styles.TooltipReference,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className
  });
}, {
  themeKey: 'Tooltip.Reference'
});
var TooltipReference = createComponent.createComponent(function (props) {
  var tooltipReferenceProps = useTooltipReferenceProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: tooltipReferenceProps
  });
}, {
  attach: {
    useProps: useTooltipReferenceProps,
    displayName: 'Tooltip.Reference'
  },
  themeKey: 'Tooltip.Reference'
}); ////////////////////////////////////////////////////////////

var useTooltipArrowProps = createHook.createHook(function (props, _ref3) {
  var themeKey = _ref3.themeKey,
      themeKeyOverride = _ref3.themeKeyOverride;

  var unstable_arrowRef = props.unstable_arrowRef,
      unstable_arrowStyles = props.unstable_arrowStyles,
      placement = props.placement,
      size = props.size,
      restProps = __chunk_1._objectWithoutPropertiesLoose(props, ["unstable_arrowRef", "unstable_arrowStyles", "placement", "size"]);

  var tooltipArrowProps = reakit.useTooltipArrow({
    placement: placement,
    size: size,
    unstable_arrowRef: unstable_arrowRef,
    unstable_arrowStyles: unstable_arrowStyles
  }, restProps);
  var boxProps = Box.Box.useProps(__chunk_1._objectSpread2(__chunk_1._objectSpread2({}, props), tooltipArrowProps));
  var className = useClassName.useClassName({
    style: styles.TooltipArrow,
    styleProps: props,
    themeKey: themeKey,
    themeKeyOverride: themeKeyOverride,
    prevClassName: boxProps.className
  });
  return __chunk_1._objectSpread2(__chunk_1._objectSpread2({}, boxProps), {}, {
    className: className
  });
}, {
  themeKey: 'Tooltip.Arrow'
});
var TooltipArrow = createComponent.createComponent(function (props) {
  var tooltipArrowProps = useTooltipArrowProps(props);
  return createElement.createElement({
    children: props.children,
    component: reakit.Box,
    use: props.use,
    htmlProps: tooltipArrowProps
  });
}, {
  attach: {
    useProps: useTooltipArrowProps,
    displayName: 'Tooltip.Arrow'
  },
  themeKey: 'Tooltip.Arrow'
});

exports.Tooltip = Tooltip;
exports.TooltipArrow = TooltipArrow;
exports.TooltipContent = TooltipContent;
exports.TooltipReference = TooltipReference;
