import * as React from 'react';
import { Omit } from '../types';
import { BoxProps } from '../Box';
import { ButtonProps } from '../Button';
import { IconProps } from '../Icon';
export declare type LocalAlertProps = {
    accent?: true | 'top' | 'bottom';
    accentSize?: string;
    countdown?: number;
    hasIcon?: boolean;
    isInline?: boolean;
    onClickClose?: ButtonProps['onClick'];
    showCloseButton?: boolean;
    title?: string;
    type?: string;
    closeButtonProps?: Omit<ButtonProps, 'children'>;
    closeButtonIconProps?: Omit<IconProps, 'icon'>;
    iconProps?: Omit<IconProps, 'icon'>;
};
export declare type AlertProps = BoxProps & LocalAlertProps;
export declare type AlertContextOptions = AlertProps & {
    descriptionId?: string;
    titleId?: string;
    themeKey?: string;
    themeKeyOverride?: string;
};
export declare const AlertContext: React.Context<AlertContextOptions>;
export declare const Alert: React.ForwardRefExoticComponent<Pick<AlertProps, "slot" | "style" | "title" | "clipPath" | "filter" | "marker" | "mask" | "use" | "children" | "bottom" | "left" | "right" | "top" | "css" | "background" | "variant" | "colorMode" | "alignContent" | "alignItems" | "alignSelf" | "animationDelay" | "animationDirection" | "animationDuration" | "animationFillMode" | "animationIterationCount" | "animationName" | "animationPlayState" | "animationTimingFunction" | "appearance" | "backfaceVisibility" | "backgroundAttachment" | "backgroundBlendMode" | "backgroundClip" | "backgroundColor" | "backgroundImage" | "backgroundOrigin" | "backgroundPosition" | "backgroundRepeat" | "backgroundSize" | "blockSize" | "borderBlockColor" | "borderBlockEndColor" | "borderBlockEndStyle" | "borderBlockEndWidth" | "borderBlockStartColor" | "borderBlockStartStyle" | "borderBlockStartWidth" | "borderBlockStyle" | "borderBlockWidth" | "borderBottomColor" | "borderBottomLeftRadius" | "borderBottomRightRadius" | "borderBottomStyle" | "borderBottomWidth" | "borderCollapse" | "borderImageOutset" | "borderImageRepeat" | "borderImageSlice" | "borderImageSource" | "borderImageWidth" | "borderInlineColor" | "borderInlineEndColor" | "borderInlineEndStyle" | "borderInlineEndWidth" | "borderInlineStartColor" | "borderInlineStartStyle" | "borderInlineStartWidth" | "borderInlineStyle" | "borderInlineWidth" | "borderLeftColor" | "borderLeftStyle" | "borderLeftWidth" | "borderRightColor" | "borderRightStyle" | "borderRightWidth" | "borderSpacing" | "borderTopColor" | "borderTopLeftRadius" | "borderTopRightRadius" | "borderTopStyle" | "borderTopWidth" | "boxDecorationBreak" | "boxShadow" | "boxSizing" | "breakAfter" | "breakBefore" | "breakInside" | "captionSide" | "caretColor" | "clear" | "color" | "colorAdjust" | "columnCount" | "columnFill" | "columnGap" | "columnRuleColor" | "columnRuleStyle" | "columnRuleWidth" | "columnSpan" | "columnWidth" | "contain" | "content" | "counterIncrement" | "counterReset" | "counterSet" | "cursor" | "direction" | "display" | "emptyCells" | "flexBasis" | "flexDirection" | "flexGrow" | "flexShrink" | "flexWrap" | "float" | "fontFamily" | "fontFeatureSettings" | "fontKerning" | "fontLanguageOverride" | "fontOpticalSizing" | "fontSize" | "fontSizeAdjust" | "fontStretch" | "fontStyle" | "fontSynthesis" | "fontVariant" | "fontVariantCaps" | "fontVariantEastAsian" | "fontVariantLigatures" | "fontVariantNumeric" | "fontVariantPosition" | "fontVariationSettings" | "fontWeight" | "gridAutoColumns" | "gridAutoFlow" | "gridAutoRows" | "gridColumnEnd" | "gridColumnStart" | "gridRowEnd" | "gridRowStart" | "gridTemplateAreas" | "gridTemplateColumns" | "gridTemplateRows" | "hangingPunctuation" | "height" | "hyphens" | "imageOrientation" | "imageResolution" | "initialLetter" | "inlineSize" | "inset" | "insetBlock" | "insetBlockEnd" | "insetBlockStart" | "insetInline" | "insetInlineEnd" | "insetInlineStart" | "isolation" | "justifyContent" | "justifyItems" | "justifySelf" | "letterSpacing" | "lineBreak" | "lineHeight" | "lineHeightStep" | "listStyleImage" | "listStylePosition" | "listStyleType" | "marginBlock" | "marginBlockEnd" | "marginBlockStart" | "marginBottom" | "marginInline" | "marginInlineEnd" | "marginInlineStart" | "marginLeft" | "marginRight" | "marginTop" | "maskBorderMode" | "maskBorderOutset" | "maskBorderRepeat" | "maskBorderSlice" | "maskBorderSource" | "maskBorderWidth" | "maskClip" | "maskComposite" | "maskImage" | "maskMode" | "maskOrigin" | "maskPosition" | "maskRepeat" | "maskSize" | "maskType" | "maxBlockSize" | "maxHeight" | "maxInlineSize" | "maxLines" | "maxWidth" | "minBlockSize" | "minHeight" | "minInlineSize" | "minWidth" | "mixBlendMode" | "objectFit" | "objectPosition" | "offsetAnchor" | "offsetDistance" | "offsetPath" | "offsetPosition" | "offsetRotate" | "opacity" | "order" | "orphans" | "outlineColor" | "outlineOffset" | "outlineStyle" | "outlineWidth" | "overflow" | "overflowWrap" | "overflowX" | "overflowY" | "paddingBlock" | "paddingBlockEnd" | "paddingBlockStart" | "paddingBottom" | "paddingInline" | "paddingInlineEnd" | "paddingInlineStart" | "paddingLeft" | "paddingRight" | "paddingTop" | "pageBreakAfter" | "pageBreakBefore" | "pageBreakInside" | "perspective" | "perspectiveOrigin" | "placeContent" | "pointerEvents" | "position" | "quotes" | "resize" | "rowGap" | "rubyAlign" | "rubyMerge" | "rubyPosition" | "scrollBehavior" | "scrollPadding" | "scrollPaddingBlock" | "scrollPaddingBlockEnd" | "scrollPaddingBlockStart" | "scrollPaddingBottom" | "scrollPaddingInline" | "scrollPaddingInlineEnd" | "scrollPaddingInlineStart" | "scrollPaddingLeft" | "scrollPaddingRight" | "scrollPaddingTop" | "scrollSnapAlign" | "scrollSnapStop" | "scrollSnapType" | "shapeImageThreshold" | "shapeMargin" | "shapeOutside" | "tabSize" | "tableLayout" | "textAlign" | "textAlignLast" | "textCombineUpright" | "textDecorationColor" | "textDecorationLine" | "textDecorationSkip" | "textDecorationStyle" | "textEmphasisColor" | "textEmphasisPosition" | "textEmphasisStyle" | "textIndent" | "textJustify" | "textOrientation" | "textOverflow" | "textShadow" | "textTransform" | "textUnderlinePosition" | "transform" | "transformBox" | "transformOrigin" | "transformStyle" | "transitionDelay" | "transitionDuration" | "transitionProperty" | "transitionTimingFunction" | "translate" | "unicodeBidi" | "userSelect" | "verticalAlign" | "visibility" | "whiteSpace" | "widows" | "width" | "willChange" | "wordBreak" | "wordSpacing" | "wordWrap" | "writingMode" | "zIndex" | "all" | "animation" | "border" | "borderBlock" | "borderBlockEnd" | "borderBlockStart" | "borderBottom" | "borderColor" | "borderImage" | "borderInline" | "borderInlineEnd" | "borderInlineStart" | "borderLeft" | "borderRadius" | "borderRight" | "borderStyle" | "borderTop" | "borderWidth" | "columnRule" | "columns" | "flex" | "flexFlow" | "font" | "gap" | "grid" | "gridArea" | "gridColumn" | "gridRow" | "gridTemplate" | "listStyle" | "margin" | "maskBorder" | "offset" | "outline" | "padding" | "placeItems" | "placeSelf" | "textDecoration" | "textEmphasis" | "transition" | "clip" | "fontVariantAlternates" | "gridColumnGap" | "gridGap" | "gridRowGap" | "alignmentBaseline" | "baselineShift" | "clipRule" | "dominantBaseline" | "fill" | "fillOpacity" | "fillRule" | "floodColor" | "floodOpacity" | "glyphOrientationVertical" | "lightingColor" | "markerEnd" | "markerMid" | "markerStart" | "stroke" | "strokeDasharray" | "strokeDashoffset" | "strokeLinecap" | "strokeLinejoin" | "strokeMiterlimit" | "strokeOpacity" | "strokeWidth" | "running" | "hidden" | "page" | "flow" | "caret" | "rest" | "wrapElement" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "className" | "contentEditable" | "contextMenu" | "dir" | "draggable" | "id" | "lang" | "placeholder" | "spellCheck" | "tabIndex" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "inputMode" | "is" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onAuxClick" | "onAuxClickCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "key" | "themeKey" | "unstable_system" | "_hover" | "_hoveractive" | "_focus" | "_active" | "_visited" | "azimuth" | "backgroundImageTransform" | "blockStep" | "blockStepAlign" | "blockStepInsert" | "blockStepRound" | "blockStepSize" | "bookmarkLabel" | "bookmarkLevel" | "bookmarkState" | "borderBoundary" | "borderImageTransform" | "boxSnap" | "caretAnimation" | "caretShape" | "chains" | "colorInterpolationFilters" | "continue" | "cue" | "cueAfter" | "cueBefore" | "elevation" | "fillBreak" | "fillColor" | "fillImage" | "fillOrigin" | "fillPosition" | "fillRepeat" | "fillSize" | "floatDefer" | "floatOffset" | "floatReference" | "flowFrom" | "flowInto" | "fontMaxSize" | "fontMinSize" | "fontPalette" | "fontPresentation" | "footnoteDisplay" | "footnotePolicy" | "hyphenateCharacter" | "hyphenateLimitChars" | "hyphenateLimitLast" | "hyphenateLimitLines" | "hyphenateLimitZone" | "initialLetterAlign" | "initialLetterWrap" | "lineGrid" | "lineSnap" | "marginX" | "marginY" | "markerKnockoutLeft" | "markerKnockoutRight" | "markerPattern" | "markerSegment" | "markerSide" | "marqueeDirection" | "marqueeLoop" | "marqueeSpeed" | "marqueeStyle" | "navDown" | "navLeft" | "navRight" | "navUp" | "offsetAfter" | "offsetBefore" | "offsetEnd" | "offsetStart" | "overflowStyle" | "paddingX" | "paddingY" | "pause" | "pauseAfter" | "pauseBefore" | "pitch" | "pitchRange" | "playDuring" | "presentationLevel" | "regionFragment" | "restAfter" | "restBefore" | "richness" | "rotation" | "rotationPoint" | "scrollSnapMargin" | "scrollSnapMarginBlock" | "scrollSnapMarginBlockEnd" | "scrollSnapMarginBlockStart" | "scrollSnapMarginBottom" | "scrollSnapMarginInline" | "scrollSnapMarginInlineEnd" | "scrollSnapMarginInlineStart" | "scrollSnapMarginLeft" | "scrollSnapMarginRight" | "scrollSnapMarginTop" | "scrollbarGutter" | "shapeInside" | "speak" | "speakAs" | "speakHeader" | "speakNumeral" | "speakPunctuation" | "speechRate" | "stress" | "stringSet" | "strokeAlign" | "strokeAlignment" | "strokeBreak" | "strokeColor" | "strokeDashCorner" | "strokeDashJustify" | "strokeDashadjust" | "strokeDashcorner" | "strokeImage" | "strokeOrigin" | "strokePosition" | "strokeRepeat" | "strokeSize" | "textAlignAll" | "textSpaceCollapse" | "textSpaceTrim" | "textSpacing" | "textWrap" | "voiceBalance" | "voiceDuration" | "voiceFamily" | "voicePitch" | "voiceRange" | "voiceRate" | "voiceStress" | "voiceVolume" | "volume" | "wrapAfter" | "wrapBefore" | "wrapFlow" | "wrapInside" | "wrapThrough" | "altitude" | "overrides" | "elementRef" | "type" | "iconProps" | "accent" | "accentSize" | "countdown" | "hasIcon" | "isInline" | "onClickClose" | "showCloseButton" | "closeButtonProps" | "closeButtonIconProps"> & React.RefAttributes<unknown>> & {
    displayName?: string;
    useProps: (props?: Partial<AlertProps>, config?: {
        themeKey?: string;
    }) => any;
};
export declare type LocalAlertIconProps = {
    iconProps?: Omit<IconProps, 'icon'>;
};
export declare type AlertIconProps = BoxProps & LocalAlertIconProps;
export declare function AlertIcon(props: AlertIconProps): JSX.Element;
export declare type LocalAlertContentProps = {};
export declare type AlertContentProps = BoxProps & LocalAlertContentProps;
export declare function AlertContent(props: AlertContentProps): JSX.Element;
export declare type LocalAlertWrapperProps = {};
export declare type AlertWrapperProps = BoxProps & LocalAlertWrapperProps;
export declare function AlertWrapper(props: AlertWrapperProps): JSX.Element;
export declare type LocalAlertAccentProps = {
    isBackground?: boolean;
};
export declare type AlertAccentProps = BoxProps & LocalAlertAccentProps;
export declare function AlertAccent(props: AlertAccentProps): JSX.Element;
export declare type LocalAlertTitleProps = {};
export declare type AlertTitleProps = BoxProps & LocalAlertTitleProps;
export declare function AlertTitle(props: AlertTitleProps): JSX.Element;
export declare type LocalAlertDescriptionProps = {};
export declare type AlertDescriptionProps = BoxProps & LocalAlertDescriptionProps;
export declare function AlertDescription(props: AlertDescriptionProps): JSX.Element;
